#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
#  File-Name:   replicationFile_communicatingRift.r   		       		
#  Date:        22/01/22                			
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
pkgs <- c('ggplot2','dplyr','tidyverse','estimatr','conflicted','cregg','Hmisc',
          'haven','magrittr','tidyr','texreg')
# Comment in below if packages need to be installed
# for (pkg in pkgs) install.packages(pkg, character.only = TRUE)
for (pkg in pkgs) library(pkg, character.only = TRUE)
conflict_prefer("filter", "dplyr")
conflict_prefer("select", "dplyr")
conflict_prefer("recode", "dplyr")
conflict_prefer("lag", "dplyr")

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Loading data ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
dataLong <- read.csv('../4_FinalData/data_communicatingRift.csv',
                     stringsAsFactors=T) 
               
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figures and Tables ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Main text
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure 1 ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
mm.approval.mp <- cj(dataLong, approvalMP ~ reason + term + party + 
   gender + numberOfRebels + impact + publicSupport + bill + billDirection, 
   id= ~ resid, by= ~sharedPosition + welcomed, estimate='mm') %>% 
   mutate(variable='Approval of MP')
mm.approval.leader <- cj(dataLong, approvalLeader ~ reason + term + party + 
   gender + numberOfRebels + impact + publicSupport + bill  + billDirection, 
   id= ~ resid, by= ~sharedPosition + welcomed, estimate='mm') %>% 
   mutate(variable='Approval of leadership')

pdf('figure1.pdf',height=5)
rbind(mm.approval.mp,mm.approval.leader) %>%
   filter(feature=='reason') %>%
   ggplot(aes(x=reorder(level,desc(level)),y=estimate,ymin=lower,ymax=upper,
              color=variable,fill=variable)) +
   facet_grid(welcomed~sharedPosition) +
   geom_pointrange(position=position_dodge2(width=.6),size=.2) +
   coord_flip() + 
   scale_color_manual(values=c('black','steelblue1')) +
   scale_fill_manual(values=c('black','steelblue1')) +
   scale_shape_manual(values=c(16,24)) +
   labs(x='',y='Marginal mean') + theme_bw() +
   theme(legend.position='bottom',legend.title=element_blank(),
         axis.text.y=element_text(size=8),strip.background=element_blank())
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Appendix
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure A.1 ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
mm.approval.mp <- cj(dataLong %>% mutate(vignette=factor(vignette)),
   approvalMP ~ reason + term + party + gender + numberOfRebels + impact + 
   publicSupport + bill + billDirection, 
   id= ~ resid, by= ~sharedPosition + welcomed + vignette, estimate='mm') %>% 
   mutate(variable='Approval of MP')
mm.approval.leader <- cj(dataLong %>% mutate(vignette=factor(vignette)),
   approvalLeader ~ reason + term + party + gender + numberOfRebels + impact + 
   publicSupport + bill + billDirection, 
   id= ~ resid, by= ~sharedPosition + welcomed + vignette, estimate='mm') %>% 
   mutate(variable='Approval of leadership')

pdf('figureA1.pdf',height=5)
rbind(mm.approval.mp,mm.approval.leader) %>%
   filter(feature=='reason') %>%
   ggplot(aes(x=reorder(level,desc(level)),y=estimate,ymin=lower,ymax=upper,
              color=variable,fill=variable),shape=vignette) +
   facet_grid(welcomed~sharedPosition) +
   geom_pointrange(position=position_dodge2(width=.6),size=.2) +
   coord_flip() + 
   scale_color_manual(values=c('black','steelblue3','steelblue1','gray')) +
   scale_fill_manual(values=c('black','steelblue3','steelblue1','gray')) +
   scale_shape_manual(values=c(16,24)) +
   labs(x='',y='Marginal mean') + theme_bw() +
   theme(legend.position='bottom',legend.title=element_blank(),
         axis.text.y=element_text(size=8),strip.background=element_blank())
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure B.2 ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
pdf('figureB2.pdf',height=6)
dataLong %>% pivot_longer(cols=c(approvalMP,approvalLeader),
   names_to='outcomeVariable',values_to='outcomeValues') %>%
   mutate(outcomeVariable=recode(outcomeVariable,'approvalMP'='Approval of MP',
      'approvalLeader'='Approval of leadership')) %>%
   group_by(country,outcomeVariable,outcomeValues) %>%
   summarise(n=n()) %>% mutate(N=max(cumsum(n)),prop=n/N) %>%
   ggplot(aes(y=prop,x=outcomeValues)) +
   facet_grid(country~outcomeVariable) +    
   geom_col(color='black') +
   scale_x_continuous(breaks=seq(1,7,1),labels=c('Strongly disagree',rep('',5),
                                                 'Strongly agree')) +
   labs(y='Relative frequency',x='') +
   theme_bw() +
   theme(axis.text.x=element_text(angle=45,hjust=1))
dev.off() 

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure B.3 and B.4 ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
mm.approval.mp <- cj(dataLong,approvalMP ~ leader + reason + term + 
   party + gender + numberOfRebels + impact + publicSupport + bill + billDirection, 
   by= ~sharedPosition + country, id= ~resid, estimate='mm') %>% 
   mutate(variable='Approval of MP')
mm.approval.leader <- cj(dataLong,approvalLeader ~ leader + reason + term + 
   party + gender + numberOfRebels + impact + publicSupport + bill + billDirection, 
   by= ~sharedPosition + country, id= ~resid, estimate='mm') %>% 
   mutate(variable='Approval of leadership')
mm <- rbind(mm.approval.mp,mm.approval.leader)

pdf('figureB3.pdf',height=8)
mm %>% filter(sharedPosition=='MP and voter share policy position') %>%
   ggplot(aes(x=reorder(level,desc(level)),y=estimate,ymin=lower,ymax=upper,
              color=country,fill=country)) +
   facet_grid(~variable) +
   geom_pointrange(position=position_dodge2(width=.6),size=.2,shape=21) +
   coord_flip() + 
   scale_color_manual(values=c('black','black','steelblue1','steelblue1')) +
   scale_fill_manual(values=c('black','white','steelblue1','white')) +
   guides(color=guide_legend(ncol=2)) +
   labs(x='',y='Marginal mean') + theme_bw() +
   theme(legend.position='bottom',legend.title=element_blank(),
         axis.text.y=element_text(size=8),strip.background=element_blank())
dev.off()

pdf('figureB4.pdf',height=8)
mm %>% filter(sharedPosition=='MP and voter differ in policy position') %>%
   ggplot(aes(x=reorder(level,desc(level)),y=estimate,ymin=lower,ymax=upper,
              color=country,fill=country)) +
   facet_grid(~variable) +
   geom_pointrange(position=position_dodge2(width=.6),size=.2,shape=21) +
   coord_flip() + 
   scale_color_manual(values=c('black','black','steelblue1','steelblue1')) +
   scale_fill_manual(values=c('black','white','steelblue1','white')) +
   guides(color=guide_legend(ncol=2)) +
   labs(x='',y='Marginal mean') + theme_bw() +
   theme(legend.position='bottom',legend.title=element_blank(),
         axis.text.y=element_text(size=8),strip.background=element_blank())
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure B.5 ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
mm.approval.mp <- cj(dataLong,approvalMP ~ reason, 
   id= ~ resid, by= ~sharedPosition + welcomed + salienceSplit, estimate='mm') %>% 
   mutate(variable='Approval of MP')
mm.approval.leader <- cj(dataLong,approvalLeader ~ reason, 
   id= ~ resid, by= ~sharedPosition + welcomed + salienceSplit, estimate='mm') %>% 
   mutate(variable='Approval of leadership')

pdf('figureB5.pdf',height=5)
rbind(mm.approval.mp,mm.approval.leader) %>%
   ggplot(aes(x=reorder(level,desc(level)),y=estimate,ymin=lower,ymax=upper,
              color=variable,fill=variable,shape=salienceSplit)) +
   facet_grid(welcomed~sharedPosition) +
   geom_pointrange(position=position_dodge2(width=.6),size=.2) +
   coord_flip() + 
   scale_color_manual(values=c('black','steelblue1')) +
   scale_fill_manual(values=c('black','steelblue1')) +
   scale_shape_manual(values=c(16,24)) +
   guides(color=guide_legend(nrow = 2, byrow = TRUE),
          shape=guide_legend(nrow = 2, byrow = TRUE)) + 
   labs(x='',y='Marginal mean') + theme_bw() +
   theme(legend.position='bottom',legend.title=element_blank(),
         axis.text.y=element_text(size=8),strip.background=element_blank())
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure B.6
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
D <- dataLong %>% 
   filter(!is.na(voteChoice)&
             sharedPosition=='MP and voter differ in policy position') %>% 
   droplevels() 

mm <- rbind(
   cj(D,approvalMP ~ reason, 
      id= ~ resid, by= ~welcomed + voteChoice, estimate='mm') %>% 
      mutate(variable='Approval of MP'),
   cj(D,approvalLeader ~ reason, 
      id= ~ resid, by=~welcomed + voteChoice, estimate='mm') %>% 
      mutate(variable='Approval of leadership'))

pdf('figureB6.pdf',height=5,width=8)
mm %>% 
   filter(voteChoice!='I prefer not to answer'&
      voteChoice!='I would vote blank or invalid') %>%
   mutate(country=ifelse(
      voteChoice=='Conservative'|voteChoice=='Liberal Democrats'|
      voteChoice=='Labour'|voteChoice=='Greens','United Kingdom',
      ifelse(voteChoice=="Fratelli d'Italia"|voteChoice=='Lega'|
             voteChoice=='Movimento 5 Stelle'|voteChoice=='Partito Democratico','Italy',
      ifelse(voteChoice=='AfD'|voteChoice=='CDU/CSU'|voteChoice=='FDP'|
            voteChoice=='SPD'|voteChoice=='Bündnis 90/Die Grünen'|
            voteChoice=='Die Linke','Germany',
      ifelse(voteChoice=='Other'|voteChoice=='I would not vote',' ','France'))))) %>%
   filter(voteChoice=='Bündnis 90/Die Grünen'|voteChoice=='CDU/CSU'|
         voteChoice=='Conservative'|
         voteChoice=='Labour'|voteChoice=='Le Rassemblement National'|
         voteChoice=='La République en Marche'|
         voteChoice=='Lega'|voteChoice=='Movimento 5 Stelle') %>%
   mutate(voteChoice=recode(voteChoice,
      'La République en Marche'='La République\nen Marche',
      'Movimento 5 Stelle'='Movimento\n5 Stelle',
      'Le Rassemblement National'='Le\nRassemblement\nNational',
      'Bündnis 90/Die Grünen'='Bündnis 90/\nDie Grünen')) %>%
   ggplot(aes(x=level,y=estimate,ymin=lower,ymax=upper,
              fill=variable,color=variable)) +
   facet_grid(welcomed~voteChoice) +
   geom_pointrange(position=position_dodge2(width=.6),size=.2) +
   coord_flip() + 
   scale_color_manual(values=c('black','steelblue1')) +
   scale_fill_manual(values=c('black','steelblue1')) +
   scale_shape_manual(values=c(16,24)) +
   scale_y_continuous(breaks = c(3.5,4,4.5,5),labels = c(3.5,4,4.5,5)) +
   labs(x='',y='Marginal mean') + theme_bw() +
   theme(legend.position='bottom',legend.title=element_blank(),
         axis.text.y=element_text(size=8),strip.background=element_blank(),
         strip.text.x=element_text(size=6),axis.text.x=element_text(size=6))
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure B.7
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
mm.approval.mp <- cj(dataLong, approvalMP ~ reason + term + party + 
   gender + numberOfRebels + impact + publicSupport + bill + billDirection, 
   id= ~ resid, by= ~sharedPosition + welcomed + country, estimate='mm') 

pdf("figureB7.pdf",height=5)
mm.approval.mp %>%
   filter(feature=='reason') %>%
   ggplot(aes(x=reorder(level,desc(level)),y=estimate,ymin=lower,ymax=upper,
              color=country,fill=country)) +
   facet_grid(welcomed~sharedPosition) +
   geom_pointrange(position=position_dodge2(width=.6),size=.2,shape=21) +
   coord_flip() + 
   scale_color_manual(values=c('black','black','steelblue1','steelblue1')) +
   scale_fill_manual(values=c('black','white','steelblue1','white')) +
   scale_shape_manual(values=c(16,24)) +
   labs(x='',y='Marginal mean') + theme_bw() +
   theme(legend.position='bottom',legend.title=element_blank(),
         axis.text.y=element_text(size=8),strip.background=element_blank())
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Figure B.8
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
mm.approval.leader <- cj(dataLong,approvalLeader ~ reason + term + party + 
   gender + numberOfRebels + impact + publicSupport + bill + billDirection, 
   id= ~ resid, by= ~sharedPosition + welcomed + country, estimate='mm') 

pdf('figureB8.pdf',height=5)
mm.approval.leader %>%
   filter(feature=='reason') %>%
   ggplot(aes(x=reorder(level,desc(level)),y=estimate,ymin=lower,ymax=upper,
              color=country,fill=country)) +
   facet_grid(welcomed~sharedPosition) +
   geom_pointrange(position=position_dodge2(width=.6),size=.2,shape=21) +
   coord_flip() + 
   scale_color_manual(values=c('black','black','steelblue1','steelblue1')) +
   scale_fill_manual(values=c('black','white','steelblue1','white')) +
   scale_shape_manual(values=c(16,24)) +
   labs(x='',y='Marginal mean') + theme_bw() +
   theme(legend.position='bottom',legend.title=element_blank(),
         axis.text.y=element_text(size=8),strip.background=element_blank())
dev.off()

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Table B.2 ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
m <- dataLong %>% 
   lm_robust(approvalMP~sharedPosition+vignette+country, clusters=resid,data=.)

htmlreg(m,digits=3, single.row=F, include.ci=F, 
   custom.coef.names=c('Constant','MP and voter share policy position',
      'Vignette number','Germany','Italy','United Kingdom'), 
   reorder.coef=c(2, 3, 4, 5, 6, 1), file = "tableB2.doc", caption='')

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Table B.3 ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
m <- dataLong %>%
   mutate(reason=factor(reason, levels=c('Voters were against bill',
      'Against personal convictions','Experts are against bill',
      'Bill does not go far enough','Bill bad for society, benefitting only few', 
      'Badly drafted bill'))) %>% 
   group_by(sharedPosition,welcomed)  %>%
   do(m=lm_robust(approvalMP ~ reason + term + party + gender + numberOfRebels + 
      impact + publicSupport + bill + billDirection + vignette + country, 
      clusters=resid, data=.))

htmlreg(
   list(m$m[[1]],m$m[[2]],m$m[[3]],m$m[[4]]),
   digits=3, single.row=F, include.ci=F,omit.coef="billDirection",
   custom.coef.names=c(
      'Constant','Against personal convictions','Experts are against bill',
      'Bill does not go far enough','Bill bad for society, benefitting only few',
      'Badly drafted bill','Third term','Opposition','Male MP',
      'Only rebel','Pivotal','Public supports','Immigration',
      'Regulations','Spending and taxes','Ties to EU',
      'Vignette number','Germany','Italy','United Kingdom'),
   reorder.coef=c(2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,1), 
   file="tableB3.doc", caption='')

#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
# Table B.4 ====
#+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#
m <- dataLong %>%
   mutate(reason=factor(reason, levels=c('Voters were against bill',
      'Against personal convictions','Experts are against bill',
      'Bill does not go far enough','Bill bad for society, benefitting only few', 
      'Badly drafted bill'))) %>% 
   group_by(sharedPosition,welcomed)  %>%
   do(m=lm_robust(approvalLeader ~ reason + term + party + gender + numberOfRebels + 
      impact + publicSupport + bill + billDirection + vignette + country, 
      clusters=resid, data=.))

htmlreg(
   list(m$m[[1]],m$m[[2]],m$m[[3]],m$m[[4]]),
   digits=3, single.row=F, include.ci=F,omit.coef="billDirection",
   custom.coef.names=c(
      'Constant','Against personal convictions','Experts are against bill',
      'Bill does not go far enough','Bill bad for society, benefitting only few',
      'Badly drafted bill','Third term','Opposition','Male MP',
      'Only rebel','Pivotal','Public supports','Immigration',
      'Regulations','Spending and taxes','Ties to EU',
      'Vignette number','Germany','Italy','United Kingdom'),
   reorder.coef=c(2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17,18,19,20,1), 
   file="tableB4.doc", caption='')
